OC.L10N.register(
    "tasks",
    {
    "Important" : "Važno",
    "Today" : "Danas",
    "Week" : "Sedmica",
    "All" : "Svi",
    "Current" : "Trenutno",
    "Completed" : "Zavrženo",
    "Tasks" : "Zadaci",
    "Can edit" : "Can edit",
    "Edit" : "Izmjeni",
    "Export" : "Izvezi",
    "Delete" : "Obriši",
    "Unshare" : "Prestani  dijeliti",
    "Name" : "Ime",
    "Restore" : "Obnovi",
    "Cancel" : "Odustani",
    "Email" : "E-pošta",
    "Close" : "Zatvori",
    "Tomorrow" : "Sutra",
    "Notes" : "Notes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
